<?php
/**
 * Plugin Name: BuddyPress Analytics Lite by Dessky
 * Plugin URI:  https://dessky.com/plugin/buddypress-analytics-plugin/
 * Description: Analytics plugin for BuddyPress. This is lite version of the premium BuddyPress Analytics plugin.
 * Author:      Dessky
 * Version:     1.2.1
 * Author URI:  https://dessky.com/plugins
 * Network:     false
 */

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) die;

// Consts
if(!defined('BPA_VERSION'))
    define('BPA_VERSION', '1.2.1');

   
// Install analytics tables
function bpa_databases_install() {
    
    global $wpdb;
    $bpa_db_version = "1.0";
    $collate = '';

    if ( $wpdb->has_cap( 'collation' ) ) {
		if( ! empty($wpdb->charset ) )
			$collate .= "DEFAULT CHARACTER SET $wpdb->charset";
		if( ! empty($wpdb->collate ) )
			$collate .= " COLLATE $wpdb->collate";
    }
    
    $sql = "
    CREATE TABLE {$wpdb->prefix}bpa_query (
    query_id bigint(20) NOT NULL auto_increment,
    query tinytext NOT NULL,
    count int(12) NOT NULL DEFAULT 1,
    PRIMARY KEY (query_id)
    ) $collate;
    CREATE TABLE {$wpdb->prefix}bpa_query_history (
    id bigint(20) NOT NULL auto_increment,
    query_id bigint(20) NOT NULL,
    user int(12) NOT NULL DEFAULT 0,
    ip tinytext NOT NULL,
    time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (id)
    ) $collate;
    CREATE TABLE {$wpdb->prefix}bpa_users (
    id bigint(20) NOT NULL auto_increment,
    user_id bigint(20) NOT NULL,
    count int(12) NOT NULL DEFAULT 1,
    PRIMARY KEY (id)
    ) $collate;
    CREATE TABLE {$wpdb->prefix}bpa_page (
    id bigint(20) NOT NULL auto_increment,
    page_id bigint(20) NOT NULL,
    count int(12) NOT NULL DEFAULT 1,
    PRIMARY KEY (id)
    ) $collate;
    CREATE TABLE {$wpdb->prefix}bpa_group (
    id bigint(20) NOT NULL auto_increment,
    group_id bigint(20) NOT NULL,
    statistic_id bigint(20) NOT NULL,
    PRIMARY KEY (id)
    ) $collate;
    CREATE TABLE {$wpdb->prefix}bpa_visits (
    id bigint(20) NOT NULL auto_increment,
    user_id bigint(20) NOT NULL,
    page_id bigint(20) NOT NULL,
    ip tinytext NOT NULL,
    time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (id)
    ) $collate;
    CREATE TABLE {$wpdb->prefix}bpa_time_spent (
    id bigint(20) NOT NULL auto_increment,
    user_id bigint(20) NOT NULL,
    page_id bigint(20) NOT NULL,
    ip tinytext NOT NULL,
    spent bigint(200) NOT NULL,
    time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (id)
    ) $collate;
    ";
    
    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
    dbDelta( $sql );
    
    add_option( "bpa_db_version", $bpa_db_version );
    
    if ( ! get_option('site_visitor_counter') )
	
	update_option( 'site_visitor_counter', 1 );
}
register_activation_hook( __FILE__, 'bpa_databases_install' );    
    
/**
 * Enqueue a script in the WordPress admin on options-general.php.
 *
 * @param int $hook Hook suffix for the current admin page.
 */
function bpa_selectively_enqueue_loader_script() {
	
	global $pagenow;
	
	if ( 'options-general.php' != $pagenow ) {
		return;
	}
	wp_enqueue_script( 'google_chart', 'https://www.gstatic.com/charts/loader.js', array(), BPA_VERSION );
}
add_action( 'admin_enqueue_scripts', 'bpa_selectively_enqueue_loader_script' );

/* Filters ***********************************************************/

// Add link to settings page.
add_filter( 'plugin_action_links',               'bpa_modify_plugin_action_links', 10, 2 );
add_filter( 'network_admin_plugin_action_links', 'bpa_modify_plugin_action_links', 10, 2 );

/**
 * Add Settings link to plugins area.
 * 
 * @param array  $links Links array in which we would prepend our link.
 * @param string $file  Current plugin basename.
 * @return array Processed links.
 */
function bpa_modify_plugin_action_links( $links, $file ) {
	
	// Return normal links if not BuddyPress.
	if ( plugin_basename( __FILE__ ) != $file ) {
		return $links;
	}
	
	// Add a few links to the existing links array.
	return array_merge( $links, array(
			'supportforum'    => '<a href="' . esc_url( 'https://discuss.dessky.org/t/buddypress-analytics' ) . '" target="_blank">' . esc_html__( 'Start a Discussion on our Public Support Forum', 'bpa' ) . '</a>',
			'gotoanalytics'    => '<strong><a href="' . esc_url( 'options-general.php?page=bpa_admin&tab=bpa_admin_site_query' ) . '">' . esc_html__( 'Go to Analytics', 'bpa' ) . '</a></strong>'
	) );
}

/**
 * Adds the marketing notice to admin dashboard.
 */
function bpa_marketing_notice() {
	if ( ! current_user_can( 'update_core' ) ) {
		return;
	}
	
	?>

	<div id="message" class="notice-info notice">
		<p><?php esc_html_e( 'You have successfully installed BuddyPress Analytics Lite plugin.', 'bpa' ); ?></p>
		<p><?php printf( __( 'Click here to <a href="%s">Go to Analytics</a>.', 'bpa' ), admin_url( 'options-general.php?page=bpa_admin&tab=bpa_admin_site_query' ) ); ?></p>
		<p><?php printf( __( 'Have a Question or Suggestion? <a href="%s" target="_blank">Start a Discussion</a> on our Public Support Forum.', 'bpa' ), 'https://discuss.dessky.org/t/buddypress-analytics' ); ?></p>
	</div>

	<?php
}

add_action( 'admin_notices', 'bpa_marketing_notice' );
add_action( 'network_admin_notices', 'bpa_marketing_notice' );

// On BuddyPress init, so wil not loaded at all without BP
add_action('bp_init', 'bpa_load');
function bpa_load(){
    // Smth I want to see only in wp-admin area
    if ( is_admin() && (is_super_admin() || is_network_admin()) ){
        // The main functionality
        include(dirname(__FILE__) . '/includes/bpa-core.php');

        // include the core
        include(dirname(__FILE__) . '/includes/bpa-admin.php');
        include(dirname(__FILE__) . '/includes/bpa-cssjs.php');
        
        // Check update
        include(dirname(__FILE__) . '/includes/bpa-update.php');

        // i18n support
        load_plugin_textdomain( 'bpa', false, dirname( plugin_basename( __FILE__ ) ) . '/langs/' );
    }
    
}

function analytics_load() {
    
    // chart functions
    include(dirname(__FILE__) . '/includes/bpa-chart.php');
}
add_action('init', 'analytics_load');
?>